pub enum Error {
Show 20 variants
BackendInvalidKeyValue(String),
BackendMissingBackendKey,
BackendParsingError(String),
CommandArgumentError(String),
ConfigError(String),
IO(String, Error),
BCS(String, Error),
JsonRpcReadError(&'static str, String),
JsonRpcWriteError(&'static str, String),
NetworkAddressDecodeError(String),
StorageUnavailable(&'static str, String),
StorageReadError(&'static str, &'static str, String),
StorageSigningError(&'static str, &'static str, &'static str, String),
StorageWriteError(&'static str, &'static str, String),
Timeout(&'static str, String),
UnableToParse(&'static str, String),
UnableToParseFile(String, String),
UnableToReadFile(String, String),
UnexpectedCommand(String, String),
UnexpectedError(String),
}
Tuple Fields of BackendInvalidKeyValue
Tuple Fields of BackendParsingError
Tuple Fields of CommandArgumentError
Tuple Fields of ConfigError
Tuple Fields of JsonRpcReadError
Tuple Fields of JsonRpcWriteError
Tuple Fields of NetworkAddressDecodeError
Tuple Fields of StorageUnavailable
Tuple Fields of StorageReadError
Tuple Fields of StorageSigningError
Tuple Fields of StorageWriteError
Tuple Fields of UnableToParse
Tuple Fields of UnableToParseFile
Tuple Fields of UnableToReadFile
Tuple Fields of UnexpectedCommand
Tuple Fields of UnexpectedError
Formats the value using the given formatter. Read more
Formats the value using the given formatter. Read more
The lower-level source of this error, if any. Read more
🔬 This is a nightly-only experimental API. (backtrace)
Returns a stack backtrace, if available, of where this error occurred. Read more
👎 Deprecated since 1.42.0:
use the Display impl or to_string()
👎 Deprecated since 1.33.0:
replaced by Error::source, which can support downcasting
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
Instruments this type with the provided Span, returning an
Instrumented wrapper. Read more
Instruments this type with the current Span, returning an
Instrumented wrapper. Read more
impl<T, U> Into<U> for T where
U: From<T>,
Converts the given value to a String. Read more
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.
impl<V, T> VZip<V> for T where
V: MultiLane<T>,